@@ -1,4 +1,4 @@
-class AthleteListSBh(list):
+class AthleteListSBhp(list):
     def __init__(self, a_Name, a_Dob, a_Times=[]):
         list.__init__([])
         self.Name  = a_Name
